==> mule-db-client-1.6.0-sources.jar: org/mule/db/commons/internal/domain/executor/AbstractExecutor.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */

package org.mule.db.commons.internal.domain.executor;

import org.mule.db.commons.internal.domain.connection.DbConnection;
import org.mule.db.commons.internal.domain.logger.DefaultQueryLoggerFactory;
import org.mule.db.commons.internal.domain.logger.QueryLoggerFactory;
import org.mule.db.commons.internal.domain.logger.SingleQueryLogger;
import org.mule.db.commons.internal.domain.param.InputQueryParam;
import org.mule.db.commons.internal.domain.param.OutputQueryParam;
import org.mule.db.commons.internal.domain.param.QueryParam;
import org.mule.db.commons.internal.domain.query.QueryParamValue;
import org.mule.db.commons.internal.domain.query.QueryTemplate;
import org.mule.db.commons.internal.domain.statement.StatementFactory;
import org.mule.db.commons.internal.domain.type.DbType;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.sql.CallableStatement;
import java.sql.PreparedStatement;
import java.sql.SQLException;
import java.util.List;

import static java.lang.String.format;

/**
 * Base class for query executors
 */
public abstract class AbstractExecutor {

  protected static final Logger LOGGER = LoggerFactory.getLogger(AbstractExecutor.class);

  protected final StatementFactory statementFactory;
  protected QueryLoggerFactory queryLoggerFactory = new DefaultQueryLoggerFactory();

  public AbstractExecutor(StatementFactory statementFactory) {
    this.statementFactory = statementFactory;
  }

  protected void doProcessParameters(PreparedStatement statement, QueryTemplate queryTemplate, List<QueryParamValue> paramValues,
                                     SingleQueryLogger queryLogger, DbConnection connection)
      throws SQLException {
    int valueIndex = 0;

    for (int paramIndex = 1, inputParamsSize = queryTemplate.getParams().size(); paramIndex <= inputParamsSize; paramIndex++) {
      QueryParam queryParam = queryTemplate.getParams().get(paramIndex - 1);
      if (queryParam instanceof InputQueryParam) {
        QueryParamValue param = getParamValue(paramValues, queryParam.getName());

        queryLogger.addParameter(queryTemplate.getInputParams().get(valueIndex), param.getValue());

        processInputParam(statement, paramIndex, param.getValue(), queryParam.getType(), connection);
        valueIndex++;
      }

      if (queryParam instanceof OutputQueryParam) {
        processOutputParam((CallableStatement) statement, paramIndex, queryParam.getType());
      }
    }
  }

  protected void processInputParam(PreparedStatement statement, int index, Object value, DbType type, DbConnection connection)
      throws SQLException {
    type.setParameterValue(statement, index, value, connection);
  }

  private void processOutputParam(CallableStatement statement, int index, DbType type) throws SQLException {
    type.registerOutParameter(statement, index);
  }

  private QueryParamValue getParamValue(List<QueryParamValue> paramValues, String paramName) {
    return paramValues.stream().filter(p -> p.getName().equals(paramName)).findFirst().orElseThrow(
                                                                                                   () -> new IllegalArgumentException(format("SQL Query references parameter '%s' which was not supplied as an input parameter",
                                                                                                                                             paramName)));
  }
}

==> mule-db-client-1.6.11-sources.jar: org/mule/db/commons/internal/domain/executor/AbstractExecutor.java <==
/*
 * Copyright © MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.db.commons.internal.domain.executor;

import org.mule.db.commons.internal.domain.connection.DbConnection;
import org.mule.db.commons.internal.domain.logger.DefaultQueryLoggerFactory;
import org.mule.db.commons.internal.domain.logger.QueryLoggerFactory;
import org.mule.db.commons.internal.domain.logger.SingleQueryLogger;
import org.mule.db.commons.internal.domain.param.InputQueryParam;
import org.mule.db.commons.internal.domain.param.OutputQueryParam;
import org.mule.db.commons.internal.domain.param.QueryParam;
import org.mule.db.commons.internal.domain.query.QueryParamValue;
import org.mule.db.commons.internal.domain.query.QueryTemplate;
import org.mule.db.commons.internal.domain.statement.StatementFactory;
import org.mule.db.commons.internal.domain.type.DbType;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.sql.CallableStatement;
import java.sql.PreparedStatement;
import java.sql.SQLException;
import java.util.List;

import static java.lang.String.format;

/**
 * Base class for query executors
 */
public abstract class AbstractExecutor {

  protected static final Logger LOGGER = LoggerFactory.getLogger(AbstractExecutor.class);

  protected final StatementFactory statementFactory;
  protected QueryLoggerFactory queryLoggerFactory = new DefaultQueryLoggerFactory();

  protected AbstractExecutor(StatementFactory statementFactory) {
    this.statementFactory = statementFactory;
  }

  protected void doProcessParameters(PreparedStatement statement, QueryTemplate queryTemplate, List<QueryParamValue> paramValues,
                                     SingleQueryLogger queryLogger, DbConnection connection)
      throws SQLException {
    int valueIndex = 0;

    for (int paramIndex = 1, inputParamsSize = queryTemplate.getParams().size(); paramIndex <= inputParamsSize; paramIndex++) {
      QueryParam queryParam = queryTemplate.getParams().get(paramIndex - 1);
      if (queryParam instanceof InputQueryParam) {
        QueryParamValue param = getParamValue(paramValues, queryParam.getName());

        queryLogger.addParameter(queryTemplate.getInputParams().get(valueIndex), param.getValue());

        processInputParam(statement, paramIndex, param.getValue(), queryParam.getType(), connection);
        valueIndex++;
      }

      if (queryParam instanceof OutputQueryParam) {
        processOutputParam((CallableStatement) statement, paramIndex, queryParam.getType());
      }
    }
  }

  protected void processInputParam(PreparedStatement statement, int index, Object value, DbType type, DbConnection connection)
      throws SQLException {
    type.setParameterValue(statement, index, value, connection);
  }

  private void processOutputParam(CallableStatement statement, int index, DbType type) throws SQLException {
    type.registerOutParameter(statement, index);
  }

  private QueryParamValue getParamValue(List<QueryParamValue> paramValues, String paramName) {
    return paramValues.stream().filter(p -> p.getName().equals(paramName)).findFirst().orElseThrow(
                                                                                                   () -> new IllegalArgumentException(format("SQL Query references parameter '%s' which was not supplied as an input parameter",
                                                                                                                                             paramName)));
  }
}
